@@ -50,21 +50,29 @@ struct _CtkOpenGL
 {
     GtkVBox parent;
 
-    NvCtrlAttributeHandle *handle;
+    CtrlTarget *ctrl_target;
     CtkConfig *ctk_config;
+    CtrlEvent *ctk_event;
 
     GtkWidget *sync_to_vblank_button;
     GtkWidget *allow_flipping_button;
+    GtkWidget *allow_gsync_button;
+    GtkWidget *show_gsync_visual_indicator_button;
     GtkWidget *use_conformant_clamping_button;
     GtkWidget *force_stereo_button;
     GtkWidget *xinerama_stereo_button;
     GtkWidget *stereo_eyes_exchange_button;
+    GtkWidget *stereo_swap_mode_menu;
     GtkWidget *image_settings_scale;
     GtkWidget *aa_line_gamma_button;
     GtkWidget *aa_line_gamma_scale;
     GtkWidget *show_sli_visual_indicator_button;
     GtkWidget *show_multigpu_visual_indicator_button;
-    
+    GtkWidget *show_graphics_visual_indicator_button;
+
+    gint *stereo_swap_mode_table;
+    gint stereo_swap_mode_table_size;
+
     unsigned int active_attributes;
 };
 
@@ -74,8 +82,7 @@ struct _CtkOpenGLClass
 };
 
 GType       ctk_opengl_get_type  (void) G_GNUC_CONST;
-GtkWidget*  ctk_opengl_new       (NvCtrlAttributeHandle *,
-                                  CtkConfig *, CtkEvent *);
+GtkWidget*  ctk_opengl_new       (CtrlTarget *, CtkConfig *, CtkEvent *);
 
 GtkTextBuffer *ctk_opengl_create_help(GtkTextTagTable *, CtkOpenGL *);
 
